import { ComponentWrapper, ElementWrapper } from '@cloudscape-design/test-utils-core/dom';
import ButtonWrapper from '../button';
declare class TabWrapper extends ComponentWrapper {
    findDisabledReason(): ElementWrapper | null;
}
export default class TabsWrapper extends ComponentWrapper<HTMLButtonElement> {
    static rootSelector: string;
    /**
     * Finds all tab headers and returns the clickable elements from their labels.
     */
    findTabLinks(): Array<ElementWrapper<HTMLAnchorElement | HTMLButtonElement>>;
    /**
     * Finds the tab at the given position (1-based) and returns the clickable element from its tab label.
     *
     * @param index 1-based index of the clickable element to return
     */
    findTabLinkByIndex(index: number): TabWrapper | null;
    /**
     * Finds the tab header container at the given position (1-based) and returns the element.
     *
     * @param index 1-based index of the clickable element to return
     */
    findTabHeaderContentByIndex(index: number): ElementWrapper<HTMLAnchorElement | HTMLButtonElement> | null;
    /**
     * Finds the tab with the given ID and returns the clickable element from its tab label.
     *
     * @param id ID of the clickable element to return
     */
    findTabLinkById(id: string): TabWrapper | null;
    /**
     * Finds the currently focused tab, which might not be active if disabled with a reason.
     */
    findFocusedTab(): ElementWrapper<HTMLAnchorElement | HTMLButtonElement> | null;
    /**
     * Finds the dismissible button by using the tab index.
     *
     * @param index 1-based index of the clickable element to return
     */
    findDismissibleButtonByTabIndex(index: number): ButtonWrapper | null;
    /**
     * Finds the dismissible button by using the tab id
     *
     * @param id ID of the clickable element to return
     */
    findDismissibleButtonByTabId(id: string): ButtonWrapper | null;
    /**
     * Finds the tab action by using the tab id
     * @param id ID of the clickable element to return
     */
    findActionByTabId(id: string): ElementWrapper | null;
    /**
     * Finds the tab action by using the tab index
     * @param index 1-based index of the clickable element to return
     */
    findActionByTabIndex(index: number): ElementWrapper | null;
    /**
     * Finds the currently active tab and returns the clickable element from its tab label.
     */
    findActiveTab(): ElementWrapper<HTMLAnchorElement | HTMLButtonElement> | null;
    /**
     * Finds the currently displayed tab content and returns it.
     */
    findTabContent(): ElementWrapper<HTMLDivElement> | null;
    /**
     * Finds the dismissible button for the active tab
     */
    findActiveTabDismissibleButton(): ButtonWrapper | null;
    /**
     * Finds the tab action for the active tab
     */
    findActiveTabAction(): ElementWrapper | null;
    findActions(): ElementWrapper | null;
}
export {};
